package trie.core;

import java.util.ArrayList;

public class SortedArray<T extends Comparable<T>> {
	private ArrayList<T> elements = new ArrayList<>();

	/******
	 * Wrapper method to get the ith element from elements
	 * @param i the index into elements
	 * @return the element T at spot i of elements
	 */
	public T get(int i) {
		return elements.get(i);
	}

	/******
	 * Wrapper method to find the size of elements
	 * @return the size of elements
	 */
	public int size() {
		return elements.size();
	}

	/******
	 * Insert an item into the list, preserving the sorted property,
	 * by using insertion sort.
	 * @param item the element to be inserted
	 */
	public void insert(T item) {
		int i = elements.size();
		boolean found = false;
		while (i > 0 && !found) {
			if (elements.get(i - 1).compareTo(item) > 0) {
				i--;
			} else {
				found = true;
			}
		}
		elements.add(i, item);
	}

	/******
	 * Wrapper method to remove the ith element from elements
	 * @param i the index for removal
	 */
	public void remove(int i) {
		elements.remove(i);
	}

	/******
	 * Wrapper method to remove a given value from elements
	 * @param value the item to remove
	 */
	public void remove(T item) {
		elements.remove(item);
	}
}
